@@ -20,6 +20,7 @@ from alertaclient.models.group import Group
 from alertaclient.models.heartbeat import Heartbeat
 from alertaclient.models.history import RichHistory
 from alertaclient.models.key import ApiKey
+from alertaclient.models.note import Note
 from alertaclient.models.permission import Permission
 from alertaclient.models.user import User
 from alertaclient.utils import CustomJsonEncoder, DateTime
@@ -97,12 +98,6 @@ class Client:
         }
         return self.http.put('/alert/%s/attributes' % id, data)
 
-    def add_note(self, id, note):
-        data = {
-            'note': note
-        }
-        return self.http.put('/alert/%s/note' % id, data)
-
     def delete_alert(self, id):
         return self.http.delete('/alert/%s' % id)
 
@@ -149,6 +144,27 @@ class Client:
         r = self.http.get('/alerts/tags', query)
         return r['tags']
 
+    def alert_note(self, id, text):
+        data = {
+            'text': text
+        }
+        r = self.http.put('/alert/{}/note'.format(id), data)
+        return Note.parse(r['note'])
+
+    def get_alert_notes(self, id, page=1, page_size=None):
+        r = self.http.get('/alert/{}/notes'.format(id), page=page, page_size=page_size)
+        return [Note.parse(n) for n in r['notes']]
+
+    def update_alert_note(self, id, note_id, text):
+        data = {
+            'text': text,
+        }
+        r = self.http.put('/alert/{}/note/{}'.format(id, note_id), data)
+        return Note.parse(r['note'])
+
+    def delete_alert_note(self, id, note_id):
+        return self.http.delete('/alert/{}/note/{}'.format(id, note_id))
+
     # Blackouts
     def create_blackout(self, environment, service=None, resource=None, event=None, group=None, tags=None, customer=None, start=None, duration=None, text=None):
         data = {
@@ -173,8 +189,22 @@ class Client:
         r = self.http.get('/blackouts', query)
         return [Blackout.parse(b) for b in r['blackouts']]
 
-    def update_blackout(self, id, blackout):
-        self.http.put('/blackout/%s' % id, blackout)
+    def update_blackout(self, id, **kwargs):
+        data = {
+            'customer': kwargs.get('customer'),
+            'environment': kwargs.get('environment'),
+            'service': kwargs.get('service'),
+            'resource': kwargs.get('resource'),
+            'event': kwargs.get('event'),
+            'group': kwargs.get('group'),
+            'tags': kwargs.get('tags'),
+            'startTime': kwargs.get('startTime'),
+            'endTime': kwargs.get('endTime'),
+            'text': kwargs.get('text'),
+        }
+
+        r = self.http.put('/blackout/{}'.format(id), data)
+        return Blackout.parse(r['blackout'])
 
     def delete_blackout(self, id):
         return self.http.delete('/blackout/%s' % id)
@@ -195,8 +225,13 @@ class Client:
         r = self.http.get('/customers', query)
         return [Customer.parse(c) for c in r['customers']]
 
-    def update_customer(self, id, customer):
-        self.http.put('/customer/%s' % id, customer)
+    def update_customer(self, id, **kwargs):
+        data = {
+            'match': kwargs.get('match'),
+            'customer': kwargs.get('customer')
+        }
+        r = self.http.put('/customer/{}'.format(id), data)
+        return Customer.parse(r['customer'])
 
     def delete_customer(self, id):
         return self.http.delete('/customer/%s' % id)
@@ -251,7 +286,8 @@ class Client:
             'expireTime': kwargs.get('expireTime'),
             'customer': kwargs.get('customer')
         }
-        return self.http.put('/key/{}'.format(id), data)
+        r = self.http.put('/key/{}'.format(id), data)
+        return ApiKey.parse(r['key'])
 
     def delete_key(self, id):
         return self.http.delete('/key/%s' % id)
@@ -277,7 +313,8 @@ class Client:
             'match': kwargs.get('match'),  # role
             'scopes': kwargs.get('scopes')
         }
-        return self.http.put('/perm/{}'.format(id), data)
+        r = self.http.put('/perm/{}'.format(id), data)
+        return Permission.parse(r['permission'])
 
     def delete_perm(self, id):
         return self.http.delete('/perm/%s' % id)
@@ -313,7 +350,7 @@ class Client:
         return User.parse(r['user'])
 
     def get_user(self):
-        return Permission.parse(self.http.get('/user/%s' % id)['user'])
+        return User.parse(self.http.get('/user/%s' % id)['user'])
 
     def get_user_groups(self, id):
         r = self.http.get('/user/{}/groups'.format(id))
@@ -340,7 +377,8 @@ class Client:
             'text': kwargs.get('text'),
             'email_verified': kwargs.get('email_verified')
         }
-        return self.http.put('/user/{}'.format(id), data)
+        r = self.http.put('/user/{}'.format(id), data)
+        return User.parse(r['user'])
 
     def update_me(self, **kwargs):
         data = {
@@ -351,7 +389,8 @@ class Client:
             'attributes': kwargs.get('attributes', None) or dict(),
             'text': kwargs.get('text')
         }
-        return self.http.put('/user/me', data)
+        r = self.http.put('/user/me', data)
+        return User.parse(r['user'])
 
     def update_user_attributes(self, id, attributes):
         data = {
@@ -414,12 +453,13 @@ class Client:
         r = self.http.get('/groups', query)
         return [Group.parse(g) for g in r['groups']]
 
-    def update_group(self, id, kwargs):
+    def update_group(self, id, **kwargs):
         data = {
             'name': kwargs.get('name'),
             'text': kwargs.get('text')
         }
-        return self.http.put('/group/{}'.format(id), data)
+        r = self.http.put('/group/{}'.format(id), data)
+        return Group.parse(r['group'])
 
     def add_user_to_group(self, group_id, user_id):
         return self.http.put('/group/{}/user/{}'.format(group_id, user_id))
@@ -470,6 +510,9 @@ class TokenAuth(AuthBase):
 
 class HTTPClient:
 
+    DEFAULT_PAGE_NUMBER = 1
+    DEFAULT_PAGE_SIZE = 50
+
     def __init__(self, endpoint, key=None, secret=None, token=None, username=None, password=None, timeout=30.0, ssl_verify=True, headers=None, debug=False):
         self.endpoint = endpoint
         self.auth = None
@@ -502,9 +545,9 @@ class HTTPClient:
     def get(self, path, query=None, **kwargs):
         query = query or []
         if 'page' in kwargs:
-            query.append(('page', kwargs['page']))
+            query.append(('page', kwargs.get('page') or self.DEFAULT_PAGE_NUMBER))
         if 'page_size' in kwargs:
-            query.append(('page-size', kwargs['page_size']))
+            query.append(('page-size', kwargs.get('page_size') or self.DEFAULT_PAGE_SIZE))
 
         url = self.endpoint + path + '?' + urlencode(query, doseq=True)
         try:
