@@ -20,7 +20,7 @@ def cli(obj, name, email, password, status, text):
     try:
         r = client.update_me(name=name, email=email, password=password, status=status, attributes=None, text=text)
     except Exception as e:
-        click.echo('ERROR: {}'.format(e))
+        click.echo('ERROR: {}'.format(e), err=True)
         sys.exit(1)
     if r['status'] == 'ok':
         click.echo('Updated.')
